@@ -125,7 +125,7 @@ class VerifyToken:
           permission_list = [0]  # 默认无权限, 更具获取的权限控制请求方式
         """
         if self.debug or platform.system() == 'Windows':
-            return [0, 1, 2, 4, 8, 16, 32]
+            return {'permission_list': [0, 1, 2, 4, 8, 16, 32], 'is_all_data': True}
         if not self.redis_connect:
             handle_abnormal(
                 message='计算组件未建立连接/依赖到认证中心-Redis服务，无法验证权限',
